searchData={"items":[{"type":"module","title":"Ratio","doc":"This module allows you to use Rational numbers in Elixir, to enable exact calculations with all numbers big and small.\n\n`Ratio` defines arithmetic and comparison operations to work with rational numbers.\n\n\nThis module also contains:\n- a guard-safe `is_rational/1` check.\n- a `compare/2` function for use with e.g. `Enum.sort`.\n- `to_float/1` to (lossly) convert a rational into a float.\n\n# Shorthand infix construction operator\n\nSince version 4.0, `Ratio` no longer defines an infix operator to create rational numbers.\nInstead, rational numbers are made using `Ratio.new`,\nand as the output from using an existing `Ratio` struct with a mathematical operation.\n\nIf you do want to use an infix operator such as\n`<~>` (supported in all Elixir versions)\nor `<|>` (deprecated in Elixir v1.14, the default of older versions of the `Ratio` library)\n\nyou can add the following one-liner to the module(s) in which you want to use it:\n\n```elixir\ndefdelegate numerator <~> denominator, to: Ratio, as: :new\n```","ref":"Ratio.html"},{"type":"module","title":"Inline Math Operators and Casting - Ratio","doc":"Ratio interopts with the `Numbers` library:\nIf you want to overload Elixir's builtin math operators, you can use `use Numbers, overload_operators: true`.\n\nThis also allows you to pass in a rational number as one argument\nand an integer, float or Decimal (if you have installed the `Decimal` library),\nwhich are then cast to rational numbers whenever necessary.\n\n``` elixir\ndefmodule IDoAlotOfMathHere do\n  defdelegate numerator <~> denominator, to: Ratio, as: :new\n  use Numbers, overload_operators: true\n\n  def calculate(input) do\n    num = input <~> 2\n    result = num * 2 + (3 <~> 4) * 5.0\n    result / 2\n  end\nend\n```\n\n```\niex> IDoAlotOfMathHere.calculate(42)\nRatio.new(183, 8)\n```","ref":"Ratio.html#module-inline-math-operators-and-casting"},{"type":"function","title":"Ratio.__struct__/0","doc":"A Rational number is defined as a numerator and a denominator.\nBoth the numerator and the denominator are integers.\nIf you want to match for a rational number, you can do so by matching against this Struct.\n\nNote that *directly manipulating* the struct, however, is usually a bad idea, as then there are no validity checks, nor wil the rational be simplified.\n\nUse `Ratio.new/2` instead.","ref":"Ratio.html#__struct__/0"},{"type":"function","title":"Ratio.abs/1","doc":"Returns the absolute version of the given number (which might be an integer, float or Rational).","ref":"Ratio.html#abs/1"},{"type":"function","title":"Examples - Ratio.abs/1","doc":"iex>Ratio.abs(Ratio.new(-5, 2))\n    Ratio.new(5, 2)","ref":"Ratio.html#abs/1-examples"},{"type":"function","title":"Ratio.add/2","doc":"Adds two rational numbers.\n\n    iex> Ratio.add(Ratio.new(1, 4), Ratio.new(2, 4))\n    Ratio.new(3, 4)\n\nFor ease of use, `rhs` is allowed to be an integer as well:\n\n    iex> Ratio.add(Ratio.new(1, 4), 2)\n    Ratio.new(9, 4)\n\nTo perform addition where one of the operands might be another numeric type,\nuse `Numbers.add/2` instead, as this will perform the required coercions\nbetween the number types:\n\n    iex> Ratio.add(Ratio.new(1, 3), Decimal.new(\"3.14\"))\n    ** (FunctionClauseError) no function clause matching in Ratio.add/2\n\n    iex> Numbers.add(Ratio.new(1, 3), Decimal.new(\"3.14\"))\n    Ratio.new(521, 150)","ref":"Ratio.html#add/2"},{"type":"function","title":"Ratio.ceil/1","doc":"Rounds a number (rational, integer or float) to the largest whole number larger than or equal to num.\nFor negative numbers, this means we are rounding towards negative infinity.\n\n\niex> Ratio.ceil(Ratio.new(1, 2))\n1\niex> Ratio.ceil(Ratio.new(5, 4))\n2\niex> Ratio.ceil(Ratio.new(-3, 2))\n-1\niex> Ratio.ceil(Ratio.new(400))\n400","ref":"Ratio.html#ceil/1"},{"type":"function","title":"Ratio.compare/2","doc":"Compares two rational numbers, returning `:lt`, `:eg` or `:gt`\ndepending on whether *a* is less than, equal to or greater than *b*, respectively.\n\nThis function is able to compare rational numbers against integers or floats as well.\n\nThis function accepts other types as input as well, comparing them using Erlang's Term Ordering.\nThis is mostly useful if you have a collection that contains other kinds of numbers (builtin integers or floats) as well.","ref":"Ratio.html#compare/2"},{"type":"function","title":"Ratio.denominator/1","doc":"Treats the passed *number* as a Rational number, and extracts its denominator.\nFor integers, returns `1`.","ref":"Ratio.html#denominator/1"},{"type":"function","title":"Ratio.div/2","doc":"Divides the rational number `lhs` by the rational number `rhs`.\n\n    iex> Ratio.div(Ratio.new(2, 3), Ratio.new(8, 5))\n    Ratio.new(5, 12)\n\nFor ease of use, allows `rhs` to be an integer as well as a `Ratio` struct.\n\n    iex> Ratio.div(Ratio.new(2, 3), 10)\n    Ratio.new(2, 30)\n\nTo perform division where one of the operands might be another numeric type,\nuse `Numbers.div/2` instead, as this will perform the required coercions\nbetween the number types:\n\n    iex> Ratio.div(Ratio.new(2, 3), Decimal.new(10))\n    ** (FunctionClauseError) no function clause matching in Ratio.div/2\n\n    iex> Numbers.div(Ratio.new(2, 3), Decimal.new(10))\n    Ratio.new(2, 30)","ref":"Ratio.html#div/2"},{"type":"function","title":"Ratio.eq?/2","doc":"True if *a* is equal to *b*","ref":"Ratio.html#eq?/2"},{"type":"function","title":"Ratio.equal?/2","doc":"True if *a* is equal to *b*?","ref":"Ratio.html#equal?/2"},{"type":"function","title":"Ratio.floor/1","doc":"Rounds a number (rational, integer or float) to the largest whole number less than or equal to num.\nFor negative numbers, this means we are rounding towards negative infinity.\n\n\niex> Ratio.floor(Ratio.new(1, 2))\n0\niex> Ratio.floor(Ratio.new(5, 4))\n1\niex> Ratio.floor(Ratio.new(-3, 2))\n-2","ref":"Ratio.html#floor/1"},{"type":"function","title":"Ratio.gt?/2","doc":"True if *a* is larger than or equal to *b*","ref":"Ratio.html#gt?/2"},{"type":"function","title":"Ratio.gte?/2","doc":"True if *a* is larger than or equal to *b*","ref":"Ratio.html#gte?/2"},{"type":"macro","title":"Ratio.is_rational/1","doc":"Check to see whether something is a ratioal struct.\n\nOn recent OTP versions that expose `:erlang.map_get/2` this function is guard safe.\n\niex> require Ratio\niex> Ratio.is_rational(Ratio.new(1, 2))\ntrue\niex> Ratio.is_rational(Ratio.new(10))\ntrue\niex> Ratio.is_rational(42)\nfalse\niex> Ratio.is_rational(%{})\nfalse\niex> Ratio.is_rational(\"My quick brown fox\")\nfalse","ref":"Ratio.html#is_rational/1"},{"type":"function","title":"Ratio.lt?/2","doc":"True if *a* is smaller than *b*","ref":"Ratio.html#lt?/2"},{"type":"function","title":"Ratio.lte?/2","doc":"True if *a* is smaller than or equal to *b*","ref":"Ratio.html#lte?/2"},{"type":"function","title":"Ratio.minus/1","doc":"Negates the given rational number.","ref":"Ratio.html#minus/1"},{"type":"function","title":"Examples - Ratio.minus/1","doc":"iex> Ratio.minus(Ratio.new(5, 3))\nRatio.new(-5, 3)","ref":"Ratio.html#minus/1-examples"},{"type":"function","title":"Ratio.mult/2","doc":"Multiplies two rational numbers.\n\n    iex> Ratio.mult( Ratio.new(1, 3), Ratio.new(1, 2))\n    Ratio.new(1, 6)\n\nFor ease of use, allows `rhs` to be an integer as well as a `Ratio` struct.\n\n    iex> Ratio.mult( Ratio.new(1, 3), 2)\n    Ratio.new(2, 3)\n\nTo perform multiplication where one of the operands might be another numeric type,\nuse `Numbers.mult/2` instead, as this will perform the required coercions\nbetween the number types:\n\n    iex> Ratio.mult( Ratio.new(1, 3), Decimal.new(\"3.14\"))\n    ** (FunctionClauseError) no function clause matching in Ratio.mult/2\n\n    iex> Numbers.mult( Ratio.new(1, 3), Decimal.new(\"3.14\"))\n    Ratio.new(157, 150)","ref":"Ratio.html#mult/2"},{"type":"function","title":"Ratio.new/2","doc":"Creates a new Rational number.\nThis number is simplified to the most basic form automatically.\n\nRational numbers with a `0` as denominator are not allowed.\n\nNote that it is recommended to use integer numbers for the numerator and the denominator.","ref":"Ratio.html#new/2"},{"type":"function","title":"Floats - Ratio.new/2","doc":"*If possible, don't use them.*\n\nUsing Floats for the numerator or denominator is possible, however, because base-2 floats cannot represent all base-10 fractions properly, the results might be different from what you might expect.\nSee [The Perils of Floating Point](http://www.lahey.com/float.htm) for more information about this.\n\nFloats are converted into rationals by using `Float.ratio` (since version 3.0).","ref":"Ratio.html#new/2-floats"},{"type":"function","title":"Decimals - Ratio.new/2","doc":"To use `Decimal` parameters, the [decimal](https://hex.pm/packages/decimal) library must\nbe configured in `mix.exs`.","ref":"Ratio.html#new/2-decimals"},{"type":"function","title":"Examples - Ratio.new/2","doc":"iex> Ratio.new(1, 2)\n    Ratio.new(1, 2)\n    iex> Ratio.new(100, 300)\n    Ratio.new(1, 3)\n    iex> Ratio.new(1.5, 4)\n    Ratio.new(3, 8)\n    iex> Ratio.new(Ratio.new(3, 2), 3)\n    Ratio.new(1, 2)\n    iex> Ratio.new(Ratio.new(3, 3), 2)\n    Ratio.new(1, 2)\n    iex> Ratio.new(Ratio.new(3, 2), Ratio.new(1, 3))\n    Ratio.new(9, 2)","ref":"Ratio.html#new/2-examples"},{"type":"function","title":"Ratio.numerator/1","doc":"Converts the passed *number* as a Rational number, and extracts its denominator.\nFor integers returns the passed number itself.","ref":"Ratio.html#numerator/1"},{"type":"function","title":"Ratio.pow/2","doc":"returns *x* to the *n* th power.\n\n*x* is allowed to be an integer, rational or float (in the last case, this is first converted to a rational).\n\nWill give the answer as a rational number when applicable.\nNote that the exponent *n* is only allowed to be an integer.\n\n(so it is not possible to compute roots using this function.)","ref":"Ratio.html#pow/2"},{"type":"function","title":"Examples - Ratio.pow/2","doc":"iex> Ratio.pow(Ratio.new(2), 4)\n    Ratio.new(16, 1)\n    iex> Ratio.pow(Ratio.new(2), -4)\n    Ratio.new(1, 16)\n    iex> Ratio.pow(Ratio.new(3, 2), 10)\n    Ratio.new(59049, 1024)\n    iex> Ratio.pow(Ratio.new(10), 0)\n    Ratio.new(1, 1)","ref":"Ratio.html#pow/2-examples"},{"type":"function","title":"Ratio.sign/1","doc":"Returns the sign of the given number (which might be an integer, float or Rational)\n\nThis is:\n\n - 1 if the number is positive.\n - -1 if the number is negative.\n - 0 if the number is zero.","ref":"Ratio.html#sign/1"},{"type":"function","title":"Ratio.sub/2","doc":"Subtracts the rational number *rhs* from the rational number *lhs*.\n\n    iex> Ratio.sub(Ratio.new(1, 4), Ratio.new(2, 4))\n    Ratio.new(-1, 4)\n\nFor ease of use, `rhs` is allowed to be an integer as well:\n\n    iex> Ratio.sub(Ratio.new(1, 4), 2)\n    Ratio.new(-7, 4)\n\nTo perform addition where one of the operands might be another numeric type,\nuse `Numbers.sub/2` instead, as this will perform the required coercions\nbetween the number types:\n\n    iex> Ratio.sub(Ratio.new(1, 3), Decimal.new(\"3.14\"))\n    ** (FunctionClauseError) no function clause matching in Ratio.sub/2\n\n    iex> Numbers.sub(Ratio.new(1, 3), Decimal.new(\"3.14\"))\n    Ratio.new(-421, 150)","ref":"Ratio.html#sub/2"},{"type":"function","title":"Ratio.to_float/1","doc":"Converts the given *number* to a Float. As floats do not have arbitrary precision, this operation is generally not reversible.","ref":"Ratio.html#to_float/1"},{"type":"function","title":"Ratio.to_float_error/1","doc":"Returns a tuple, where the first element is the result of `to_float(number)` and\nthe second is a conversion error.\n\nThe conversion error is calculated by subtracting the original number from the\nconversion result.","ref":"Ratio.html#to_float_error/1"},{"type":"function","title":"Examples - Ratio.to_float_error/1","doc":"iex> Ratio.to_float_error(Ratio.new(1, 2))\n    {0.5, Ratio.new(0, 1)}\n    iex> Ratio.to_float_error(Ratio.new(2, 3))\n    {0.6666666666666666, Ratio.new(-1, 27021597764222976)}","ref":"Ratio.html#to_float_error/1-examples"},{"type":"function","title":"Ratio.to_string/1","doc":"Returns a binstring representation of the Rational number.\nIf the denominator is `1` it will still be printed wrapped with `Ratio.new`.","ref":"Ratio.html#to_string/1"},{"type":"function","title":"Examples - Ratio.to_string/1","doc":"iex> Ratio.to_string Ratio.new(10, 7)\n    \"Ratio.new(10, 7)\"\n    iex> Ratio.to_string Ratio.new(10, 2)\n    \"Ratio.new(5, 1)\"","ref":"Ratio.html#to_string/1-examples"},{"type":"function","title":"Ratio.trunc/1","doc":"Returns the integer part of number.","ref":"Ratio.html#trunc/1"},{"type":"function","title":"Examples - Ratio.trunc/1","doc":"iex> Ratio.trunc(1.7)\n    1\n    iex> Ratio.trunc(-1.7)\n    -1\n    iex> Ratio.trunc(3)\n    3\n    iex> Ratio.trunc(Ratio.new(5, 2))\n    2","ref":"Ratio.html#trunc/1-examples"},{"type":"type","title":"Ratio.t/0","doc":"","ref":"Ratio.html#t:t/0"},{"type":"module","title":"Ratio.DecimalConversion","doc":"","ref":"Ratio.DecimalConversion.html"},{"type":"function","title":"Ratio.DecimalConversion.decimal_to_rational/1","doc":"","ref":"Ratio.DecimalConversion.html#decimal_to_rational/1"},{"type":"module","title":"Ratio.FloatConversion","doc":"","ref":"Ratio.FloatConversion.html"},{"type":"function","title":"Ratio.FloatConversion.float_to_rational/1","doc":"Converts a float to a rational number.\nBecause base-2 floats cannot represent all base-10 fractions properly, the results might be different from what you might expect.\nSee [The Perils of Floating Point](http://www.lahey.com/float.htm) for more information about this.","ref":"Ratio.FloatConversion.html#float_to_rational/1"},{"type":"function","title":"Examples - Ratio.FloatConversion.float_to_rational/1","doc":"iex> Ratio.FloatConversion.float_to_rational(10.0)\n    Ratio.new(10, 1)\n    iex> Ratio.FloatConversion.float_to_rational(13.5)\n    Ratio.new(27, 2)\n    iex> Ratio.FloatConversion.float_to_rational(1.1)\n    Ratio.new(2476979795053773, 2251799813685248)","ref":"Ratio.FloatConversion.html#float_to_rational/1-examples"},{"type":"exception","title":"Ratio.ComparisonError","doc":"","ref":"Ratio.ComparisonError.html"},{"type":"extras","title":"Guide/Readme","doc":"# Ratio\n\n\n[![hex.pm version](https://img.shields.io/hexpm/v/ratio.svg)](https://hex.pm/packages/ratio)\n[![Documentation](https://img.shields.io/badge/hexdocs-latest-blue.svg)](https://hexdocs.pm/ratio/index.html)\n[![ci](https://github.com/Qqwy/elixir-rational/actions/workflows/ci.yml/badge.svg)](https://github.com/Qqwy/elixir-rational/actions/workflows/ci.yml)\n\nThis library allows you to use Rational numbers in Elixir, to enable exact calculations with all numbers big and small.\n\nRatio follows the Numeric behaviour from [Numbers](https://github.com/Qqwy/elixir_number), and can therefore be used in combination with any data type that uses Numbers (such as [Tensor](https://hex.pm/packages/tensor) and [ComplexNum](https://github.com/Qqwy/elixir_complex_num)).","ref":"readme.html"},{"type":"extras","title":"Using Ratio - Guide/Readme","doc":"`Ratio` defines arithmetic and comparison operations to work with rational numbers.\n\nRational numbers can be created by using `Ratio.new/2`,\nor by calling mathematical operators where one of the two operands is already a rational number.\n\n\n#","ref":"readme.html#using-ratio"},{"type":"extras","title":"Shorthand infix construction operator - Guide/Readme","doc":"Since version 4.0, `Ratio` no longer defines an infix operator to create rational numbers.\nInstead, rational numbers are made using `Ratio.new`,\nand as the output from using an existing `Ratio` struct with a mathematical operation.\n\nIf you do want to use an infix operator such as\n`<~>` (supported in all Elixir versions)\nor `<|>` (deprecated in Elixir v1.14, the default of older versions of the `Ratio` library)\n\nyou can add the following one-liner to the module(s) in which you want to use it:\n\n```elixir\ndefdelegate numerator <~> denominator, to: Ratio, as: :new\n```\n\n#","ref":"readme.html#shorthand-infix-construction-operator"},{"type":"extras","title":"Basic functionality - Guide/Readme","doc":"Rational numbers can be manipulated using the functions in the [`Ratio`](https://hexdocs.pm/ratio/Ratio.html) module.\n\n```elixir\niex> Ratio.mult(Ratio.new(1, 3), Ratio.new(1, 2))\nRatio.new(1, 6)\niex> Ratio.div(Ratio.new(2, 3), Ratio.new(8, 5))\nRatio.new(5, 12)\niex> Ratio.pow(Ratio.new(2), 4)\nRatio.new(16, 1)\n```\n\nThe Ratio module also contains:\n- a guard-safe `is_rational/1` check.\n- a `compare/2` function for use with e.g. `Enum.sort`.\n- `to_float/1` to (lossly) convert a rational into a float.\n\n#","ref":"readme.html#basic-functionality"},{"type":"extras","title":"Inline Math Operators and Casting - Guide/Readme","doc":"Ratio interopts with the [`Numbers`](https://github.com/Qqwy/elixir-number) library:\nIf you want to overload Elixir's builtin math operators, \nyou can add `use Numbers, overload_operators: true` to your module.\n\nThis also allows you to pass in a rational number as one argument\nand an integer, float or Decimal (if you have installed the `Decimal` library),\nwhich are then cast to rational numbers whenever necessary:\n\n``` elixir\ndefmodule IDoAlotOfMathHere do\n  defdelegate numerator <~> denominator, to: Ratio, as: :new\n  use Numbers, overload_operators: true\n\n  def calculate(input) do\n     num = input <~> 2\n     result = num * 2 + (3 <~> 4) * 5.0\n     result / 2\n  end\nend\n\n```\n\n``` elixir\niex> IDoAlotOfMathHere.calculate(42)\nRatio.new(183, 8)\n```","ref":"readme.html#inline-math-operators-and-casting"},{"type":"extras","title":"Installation - Guide/Readme","doc":"The package can be installed from hex, by adding `:ratio` to your list of dependencies in `mix.exs`:\n\n        def deps do\n          [\n            {:ratio, \"~> 4.0\"}\n          ]\n        end","ref":"readme.html#installation"},{"type":"extras","title":"Changelog - Guide/Readme","doc":"- 4.0.1 - \n  - Fix compiler warnings on Elixir v1.16 (c.f. #128). Thank you, @kidq330\n- 4.0.0 - \n  - Remove infix operator `<|>` as its usage is deprecated in Elixir v1.14. This is a backwards-incompatible change. If you want to use the old syntax with the new version, add `defdelegate num <|> denom, to: Ratio, as: :new` to your module. Alternatively, you might want to use the not-deprecated `<~>` operator for this instead.\n  - Switch the `Inspect` implementation to use the form `Ratio.new(10, 20)` instead of `10 <|> 20`, related to above. This is also a backwards-incompatible change.\n  - Remove implementation of `String.Chars`, as the earlier implementation was not a (non-programmer) human-readable format.\n  - Ensure that the right-hand-side operand of calls to `Ratio.{add, sub, mult, div}/2` is allowed to be an integer for ease of use and backwards compatibility. Thank you for noticing this problem, @kipcole9 ! (c.f. #111)\n- 3.0.2 - \n  - Fixes: A bug with `<|>` when the numerator was a rational and the denuminator an integer. (c.f. #104) Thank you, @varsill!\n- 3.0.1 -\n  - Fixes:\n    - Problem where `Ratio.ceil/1` would be off-by-one (c.f. #89). Thank you, @Hajto!\n    - Problem where `Ratio.pow/2` would return an integer rather than a new Ratio.(c.f. #100). Thank you, @speeddragon!\n- 3.0.0 - \n  - All operators except `<|>` are removed from Ratio. Instead, the operators defined by [`Numbers`](https://github.com/Qqwy/elixir-number) (which `Ratio` depends on) can be used, by adding `use Numbers, overload_operators: true` to your modules. (c.f. #34)\n  - All math-based functions expect and return `Ratio` structs (rather than also working on integers and returning integers sometimes if the output turned out to be a whole number).  (c.f. #43)\n    This makes the code more efficient and more clear for users.\n    - Ratio structs representing whole numbers are no longer implicitly converted 'back' to integers, as this behaviour was confusing. (c.f. #28)\n    - If conversion to/from other number-like types is really desired, \n      use the automatic conversions provided by `Ratio.new`, `<|>` \n      or (a bit slower but more general) the math functions exposed by [`Numbers`](https://github.com/Qqwy/elixir-number).\n      Ratio ships with implementations of `Coerce.defcoercion` for Integer -> Ratio, Float -> Ratio and Decimal -> Ratio.\n  - `is_rational?/1` is replaced with the guard-safe `is_rational/1` (only exported on Erlang versions where `:erlang.map_get/2` is available, i.e. >= OTP 21.0.) (c.f. #37)\n  - `Float.ratio/1` is now used to convert floats into `Ratio` structs, rather than maintaining a hand-written version of this logic. (c.f #46) Thank you, @marcinwasowicz !\n  - A lot of property-based tests have been added to get some level of confidence of the correctness of the library's operations.\n- 2.4.2 Uses `extra_applications` in `mix.exs` to silence warnings in Elixir 1.11 and onwards.\n- 2.4.1 Fixes a bug in the decimal conversion implementation where certain decimals were not converted properly. Thank you, @iterateNZ!\n- 2.4.0 Adds optional support for automatic conversion from [Decimal](https://github.com/ericmj/decimal)s. Thank you, @kipcole !\n- 2.3.1 Removes spurious printing statement in `Rational.FloatConversion` that would output a line of text at compile-time. Fixes support for Numbers v5+ which was broken.\n- 2.3.0 Adds `trunc` and `to_floor_error` functions.\n- 2.1.1 Fixes implementation of `floor` and `ceil` which was counter-intuitive for negative numbers (it now correctly rounds towards negative infinity). \n  - Drops support for Elixir versions older than 1.4, because of use of `Integer.floor_div`.\n  - First version to support new Erlang versions (20 and onward) that have native `floor` and `ceil` functions.\n- 2.1.0 Adds optional overloaded comparison operators.\n- 2.0.0 Breaking change: Brought `Ratio.compare/2` in line with Elixir's comparison function guideline, to return `:lt | :eq | :gt`. (This used to be `-1 | 0 | 1`).\n- 1.2.9 Improved documentation. (Thanks, @morontt!)\n- 1.2.8 Adding `:numbers` to the `applications:` list, to ensure that no warnings are thrown when building releases on Elixir < 1.4.0.\n- 1.2.6, 1.2.7 Improving documentation.\n- 1.2.5 added `ceil/1` and `floor/1`.\n- 1.2.4 Fixes Elixir 1.4 warnings in the `mix.exs` file.\n- 1.2.3 Upgraded version of the `Numbers` dependency to 2.0.\n- 1.2.2 Added default argument to `Ratio.new/2`, to follow the Numeric behaviour fully, and added `Ratio.minus/1` as alias for `Ratio.negate/1` for the same reason.\n- 1.2.0 Changed name of `Ratio.mul/2` to `Ratio.mult/2`, to avoid ambiguety, and to allow incorporation with `Numbers`. Deprecation Warning was added to using `Ratio.mul/2`.\n- 1.1.1 Negative floats are now converted correctly.\n- 1.1.0 Elixir 1.3 compliance (Statefree if/else/catch clauses, etc.)\n- 1.0.0 Proper `__using__` macro, with more readable option names. Stable release.\n- 0.6.0 First public release\n- 0.0.1 First features","ref":"readme.html#changelog"},{"type":"extras","title":"Difference with the 'rational' library - Guide/Readme","doc":"Observant readers might notice that there also is a '[rational](https://hex.pm/packages/rational)' library in Hex.pm. The design idea between that library vs. this one is a bit different: `Ratio` hides the internal data representation as much as possible, and numbers are therefore only created using `Ratio.new/2`. This has as mayor advantage that the internal representation is always correct and simplified.\n\nThe Ratio library also (optionally) overrides (by virtue of the `Numbers` library) the built-in math operations `+, -, *, /, div, abs` so they work with combinations of integers, floats and rationals.\n\nFinally, Ratio follows the Numeric behaviour, which means that it can be used with any data types that follow [Numbers](https://github.com/Qqwy/elixir_number).","ref":"readme.html#difference-with-the-rational-library"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}